# File Metadata Cleaner

**Automatically removes sensitive or unwanted metadata from uploaded files to protect privacy and streamline content moderation workflows.**

## Introduction

When users upload images, PDFs, or other media, those files often contain embedded metadata such as GPS coordinates, author names, device info, or revision history. This module ensures that such metadata is **automatically cleaned** from files on upload or via manual admin actions — reducing privacy risks and keeping your file system clean.

**Solution:** File Metadata Cleaner provides an extensible framework for detecting and removing embedded metadata from supported file types using configurable processors.

## Features

- ✅ Automatically removes metadata on file upload (configurable).
- 🧼 Manual “Clean Metadata” operation available per file.
- 🧩 Plugin-based architecture for file-type-specific processors (e.g., JPEG, PDF).
- 🧪 Extensible for custom processors via plugin system.
- 🔎 Admin overview page per file showing metadata status.


### Use cases

- Government or educational websites where privacy of media is crucial.
- Agencies handling client files with confidential embedded information.
- Any site that wants to prevent unnecessary metadata from being stored in the file system.

## Post-Installation

1. **Enable the module** at `/admin/modules`.
2. Visit the **configuration page** at:  
   `/admin/config/media/file-metadata-cleaner`
3. Choose:
    - Whether files should be cleaned **automatically on upload**.
    - If you want you can edit the **processors** (JPEG, PDF, etc.) to you liking.
4. New uploaded files will be automatically cleaned (if configured).  
   Alternatively, visit an existing file's metadata page to **manually clean it**:  
   `/admin/content/files/metadata/{file_id}`

> You must have the permission `edit file metadata cleaner settings` to access configuration pages.

## Additional Requirements

- This module requires ExifTool to be available.  
  Instead of installing ExifTool manually, this module uses the Composer package [`ahmetburkan/exiftool-binary`](https://github.com/ahmetburkan/exiftool-binary).
- This provides a cross-platform ExifTool binary.

## Recommended modules/libraries

- [Media](https://www.drupal.org/project/media): For integrating file metadata cleaning into media workflows.

## Similar Projects

- [ExifTool](https://www.drupal.org/project/exiftool): Provides access to metadata via ExifTool, but doesn't automatically clean or remove it.
- [Exif](https://www.drupal.org/project/exif): Reads and displays EXIF metadata, but doesn't offer removal capabilities.
- [EXIF Manipulate](https://www.drupal.org/project/exif_manipulate): Reads and delete EXIF metadata for JPEG only. It doesn't offer the flexibility File Metadata Cleaner has.
- **What makes File Metadata Cleaner different:**  
  It's focused on *privacy and cleanup*, not just reading metadata. It integrates cleanup directly into your file management workflow.

## Supporting this Module

If this module helps your project, consider supporting its development by:
- Reporting issues or bugs in the issue queue.
- Submitting patches or plugin implementations.
- [Sponsor a feature or improvement](https://www.drupal.org/project/issues/file_metadata_cleaner).

## Community Documentation

Nothing yet. Want to contribute one?

## Notes

- Works with Drupal 10 and 11.
- Developers can easily extend this module by creating their own `FileMetadataCleanerProcessorPlugin` implementations.
- Each processor has its own configuration screen for advanced options (e.g., always strips everything and can configure what to keep).



## Future To-Do List

The following features are on the roadmap for future development:

🖼 Support for additional image formats:
- AVIF
- HEIF / HEIC
- GIF
- PNG
- WebP

🎞 Support for video formats:
- MP4
- MOV

📥 Add a queuing system to:
- Process older images in bulk.

## Maintainers

- Ahmet Burkan - [ahmetburkan](https://www.drupal.org/u/ahmetburkan)
