<?php

namespace Drupal\file_metadata_cleaner\Controller;

use Drupal\Core\Controller\ControllerBase;
use Drupal\Component\Plugin\PluginManagerInterface;
use Drupal\Core\Link;
use Drupal\Core\Url;
use Symfony\Component\DependencyInjection\ContainerInterface;

/**
 * Controller for displaying an overview of file processor plugins.
 */
class ProcessorOverviewController extends ControllerBase {

  /**
   * The file processor plugin manager.
   *
   * @var \Drupal\Component\Plugin\PluginManagerInterface
   */
  protected PluginManagerInterface $pluginManager;

  /**
   * Constructs a new ProcessorOverviewController.
   *
   * @param \Drupal\Component\Plugin\PluginManagerInterface $plugin_manager
   *   The file processor plugin manager.
   */
  public function __construct(PluginManagerInterface $plugin_manager) {
    $this->pluginManager = $plugin_manager;
  }

  /**
   * {@inheritdoc}
   */
  public static function create(ContainerInterface $container): static {
    return new static(
      $container->get('plugin.manager.file_metadata_cleaner.processor')
    );
  }

  /**
   * Displays an overview table of file processor and renders the settings form.
   *
   * @return array
   *   A render array representing the overview table and the file
   *   processor settings form.
   */
  public function overview(): array {
    $definitions = $this->pluginManager->getDefinitions();

    $rows = [];
    foreach ($definitions as $plugin_id => $definition) {
      $rows[] = [
        $plugin_id,
        $definition['label'],
        [
          'data' => Link::fromTextAndUrl(
            $this->t('Configure'),
            Url::fromRoute('file_metadata_cleaner.edit_processor', ['plugin' => $plugin_id])
          )->toRenderable(),
        ],
      ];
    }
    $build['overview'] = [
      '#type' => 'table',
      '#header' => [
        $this->t('Plugin ID'),
        $this->t('Label'),
        $this->t('Operations'),
      ],
      '#rows' => $rows,
      '#empty' => $this->t('No file processor plugins found.'),
    ];

    return $build;
  }

}
