<?php

namespace Drupal\file_metadata_cleaner\FileProcessor;

use Drupal\Core\Plugin\DefaultPluginManager;
use Drupal\Core\Cache\CacheBackendInterface;
use Drupal\Core\Extension\ModuleHandlerInterface;

/**
 * Manages file metadata processor plugins.
 */
class FileProcessorPluginManager extends DefaultPluginManager {

  /**
   * Constructs a new FileProcessorPluginManager object.
   *
   * @param \Traversable $namespaces
   *   An object that implements \Traversable which contains the root paths
   *   keyed by the corresponding namespace to look for plugin implementations.
   * @param \Drupal\Core\Cache\CacheBackendInterface $cache_backend
   *   The cache backend instance to use.
   * @param \Drupal\Core\Extension\ModuleHandlerInterface $module_handler
   *   The module handler instance.
   */
  public function __construct(
    \Traversable $namespaces,
    CacheBackendInterface $cache_backend,
    ModuleHandlerInterface $module_handler,
  ) {
    parent::__construct(
      'Plugin/FileProcessor',
      $namespaces,
      $module_handler,
      'Drupal\file_metadata_cleaner\Plugin\FileProcessor\FileProcessorInterface',
      'Drupal\file_metadata_cleaner\Annotation\FileProcessor'
    );

    $this->setCacheBackend($cache_backend, 'file_metadata_cleaner.processor_plugins');
  }

}
