<?php

namespace Drupal\file_metadata_cleaner\Form;

use Drupal\Core\Form\ConfigFormBase;
use Drupal\Core\Form\FormStateInterface;

/**
 * Provides a configuration form for File Metadata Cleaner settings.
 */
class FileMetadataCleanerSettingsForm extends ConfigFormBase {

  /**
   * {@inheritdoc}
   */
  public function getFormId() {
    return 'file_metadata_cleaner_settings_form';
  }

  /**
   * {@inheritdoc}
   */
  protected function getEditableConfigNames(): array {
    return ['file_metadata_cleaner.settings'];
  }

  /**
   * {@inheritdoc}
   */
  public function buildForm(array $form, FormStateInterface $form_state) {
    $config = $this->config('file_metadata_cleaner.settings');

    $form['clean_on_upload'] = [
      '#type' => 'checkbox',
      '#title' => $this->t('Clean metadata on upload'),
      '#default_value' => $config->get('clean_on_upload'),
      '#description' => $this->t('Check this to automatically clean metadata when files are uploaded.'),
    ];

    return parent::buildForm($form, $form_state) + $form;
  }

  /**
   * {@inheritdoc}
   */
  public function submitForm(array &$form, FormStateInterface $form_state) {
    $cleanOnUpload = $form_state->getValue('clean_on_upload');
    $this->configFactory->getEditable('file_metadata_cleaner.settings')
      ->set('clean_on_upload', $cleanOnUpload)
      ->save();

    parent::submitForm($form, $form_state);
  }

}
