<?php

namespace Drupal\file_metadata_cleaner\Plugin\FileProcessor;

use Drupal\file\FileInterface;
use Drupal\Component\Plugin\PluginInspectionInterface;

/**
 * Interface for file metadata processor plugins.
 */
interface FileProcessorInterface extends PluginInspectionInterface {

  /**
   * Checks if this processor supports the given MIME type.
   *
   * @param string $mimeType
   *   The file's MIME type.
   *
   * @return bool
   *   TRUE if the processor supports the MIME type, FALSE otherwise.
   */
  public function supports(string $mimeType): bool;

  /**
   * Returns supported metadata fields with their intended new values.
   *
   * @return array
   *   An associative array where:
   *     - The key is a metadata field name (e.g., 'Author', 'Title').
   *     - The value is one of:
   *       - An empty string ('') to remove the metadata.
   *       - A static string to overwrite the metadata (e.g., 'John Doe').
   *       - The string '-1' to preserve the original metadata value.
   */
  public function supportedMetadataWithValues(): array;

  /**
   * Processes a file and applies metadata changes.
   *
   * @param \Drupal\file\FileInterface $file
   *   The file entity to process.
   *
   * @throws \InvalidArgumentException
   *   If the file is invalid or cannot be processed.
   * @throws \Symfony\Component\Process\Exception\ProcessFailedException
   *   If the metadata processing fails.
   * @throws \Drupal\Core\Entity\EntityStorageException
   *   If the file save proces fails.
   */
  public function process(FileInterface $file): void;

}
