<?php

namespace Drupal\file_metadata_cleaner\Services;

/**
 * Defines an interface for processing metadata of files.
 *
 * Implementations can use tools like ExifTool to read and write metadata.
 */
interface MetadataProcessorInterface {

  /**
   * Reads metadata from a file.
   *
   * @param string $filePath
   *   The absolute path to the file.
   *
   * @return array
   *   An associative array of metadata, where keys are tag names.
   *
   * @throws \InvalidArgumentException
   *   Thrown when the file path is invalid or the file cannot be read.
   * @throws \Symfony\Component\Process\Exception\ProcessFailedException
   *   Thrown if the metadata extraction process fails.
   */
  public function readMetadata(string $filePath): array;

  /**
   * Writes metadata to a file.
   *
   * @param array $arguments
   *   An array of metadata arguments for the tool,
   *   e.g., ['-Author=John', '-Title=My Image'].
   * @param string $filePath
   *   The absolute path to the file.
   *
   * @return string
   *   The raw output of the metadata writing process.
   *
   * @throws \InvalidArgumentException
   *   Thrown when the file path is invalid, unreadable, or not writable.
   * @throws \Symfony\Component\Process\Exception\ProcessFailedException
   *   Thrown if the metadata writing process fails.
   */
  public function writeMetadata(array $arguments, string $filePath): string;

}
