<?php

declare(strict_types=1);

namespace Drupal\Tests\file_metadata_cleaner\Functional;

use Drupal\Tests\BrowserTestBase;

/**
 * Tests JPEG metadata processing with the ExifTool cleaner.
 *
 * @group file_metadata_cleaner
 */
class AdminPagesTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'file_metadata_cleaner',
  ];

  /**
   * The default theme required for BrowserTestBase.
   *
   * @var string
   */
  protected $defaultTheme = 'olivero';

  /**
   * Tests metadata processing of a valid JPEG file.
   */
  public function testUnauthorizedRoutes(): void {
    $adminUser = $this->drupalCreateUser(['access files overview']);
    $this->drupalLogin($adminUser);

    $this->drupalGet('/admin/config/media/file-metadata-cleaner');
    $this->assertSession()->statusCodeEquals(403);

    $this->drupalGet('/admin/config/media/file-metadata-cleaner/processors');
    $this->assertSession()->statusCodeEquals(403);

    $this->drupalGet('/admin/config/media/file-metadata-cleaner/processors/jpeg');
    $this->assertSession()->statusCodeEquals(404);
  }

  /**
   * Tests metadata processing of a valid JPEG file.
   */
  public function testAuthorizedRoutes(): void {
    $adminUser = $this->drupalCreateUser(['edit file metadata cleaner settings']);
    $this->drupalLogin($adminUser);

    $this->drupalGet('/admin/config/media/file-metadata-cleaner');
    $this->assertSession()->statusCodeEquals(200);

    $this->drupalGet('/admin/config/media/file-metadata-cleaner/processors');
    $this->assertSession()->statusCodeEquals(200);

    $this->drupalGet('/admin/config/media/file-metadata-cleaner/processor/jpeg');
    $this->assertSession()->statusCodeEquals(200);
  }

  /**
   * Tests metadata processing of a valid JPEG file.
   */
  public function testPdfProcessor(): void {
    $adminUser = $this->drupalCreateUser(['edit file metadata cleaner settings']);
    $this->drupalLogin($adminUser);
    $this->drupalGet('/admin/config/media/file-metadata-cleaner/processors');
    $this->assertSession()->statusCodeEquals(200);

    $this->assertSession()->elementExists('xpath', "//td[text()='pdf']/following-sibling::td//a[text()='Configure']")->click();
    $this->assertSession()->addressEquals('/admin/config/media/file-metadata-cleaner/processor/pdf');

    $this->assertSession()->pageTextContains('Configure metadata cleaning for processor: pdf');

    // Check the form fields exist with default values.
    $this->assertSession()->fieldValueEquals('Title', '-1');
    $this->assertSession()->fieldValueEquals('Author', 'Drupal');
    $this->assertSession()->fieldValueEquals('Subject', '-1');
    $this->assertSession()->fieldValueEquals('Keywords', '-1');
    $this->assertSession()->fieldValueEquals('Creator', '');
    $this->assertSession()->fieldValueEquals('Producer', '');

    $edit = [
      'Title' => 'New PDF Title',
      'Author' => '-1',
      'Subject' => '',
      'Keywords' => 'new, keywords',
      'Creator' => 'New Creator',
      'Producer' => 'New Producer',
    ];

    $this->submitForm($edit, 'Save configuration');

    $this->assertSession()->pageTextContains('The configuration options have been saved.');

    $metadata = $this->config('file_metadata_cleaner.settings')
      ->get('metadata.pdf');

    $this->assertEquals('New PDF Title', $metadata['Title']);
    $this->assertEquals('-1', $metadata['Author']);
    $this->assertEquals('', $metadata['Subject']);
    $this->assertEquals('new, keywords', $metadata['Keywords']);
    $this->assertEquals('New Creator', $metadata['Creator']);
    $this->assertEquals('New Producer', $metadata['Producer']);
  }

}
