<?php

namespace Drupal\Tests\file_metadata_cleaner\Functional;

use Drupal\Core\File\FileExists;
use Drupal\file\Entity\File;
use Drupal\Tests\BrowserTestBase;

/**
 * Tests the FileEntity hooks in a real environment.
 *
 * @group file_metadata_cleaner
 */
class FileEntityFunctionalTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'file',
    'user',
    'views',
    'file_metadata_cleaner',
  ];

  /**
   * The default theme required for BrowserTestBase.
   *
   * @var string
   */
  protected $defaultTheme = 'olivero';

  /**
   * Tests that on file insert works.
   */
  public function testFileInsertCleanOnUploadIsTrue(): void {
    $kernel = $this->container->get('kernel');
    $appRoot = $kernel->getAppRoot();
    $source = $appRoot . '/modules/custom/file_metadata_cleaner/tests/fixtures/London_bridge.jpeg';
    $destination = 'public://London_bridge.jpeg';

    /** @var \Drupal\Core\File\FileSystemInterface $fileSystem */
    $fileSystem = \Drupal::service('file_system');
    $fileSystem->copy($source, $destination, FileExists::Replace);

    $file = File::create(['uri' => $destination]);
    $file->setPermanent();
    $file->save();

    // Reload $file.
    $file = File::load($file->id());

    $this->assertEquals('1', $file->get('metadata_cleaned')->value);
  }

  /**
   * Tests that on file insert works.
   */
  public function testFileInsertCleanOnUploadIsFalse(): void {
    $this->config('file_metadata_cleaner.settings')
      ->set('clean_on_upload', FALSE)
      ->save();

    $kernel = $this->container->get('kernel');
    $appRoot = $kernel->getAppRoot();
    $source = $appRoot . '/modules/custom/file_metadata_cleaner/tests/fixtures/London_bridge.jpeg';
    $destination = 'public://London_bridge.jpeg';

    /** @var \Drupal\Core\File\FileSystemInterface $fileSystem */
    $fileSystem = \Drupal::service('file_system');
    $fileSystem->copy($source, $destination, FileExists::Replace);

    $file = File::create(['uri' => $destination]);
    $file->setPermanent();
    $file->save();

    // Reload $file.
    $file = File::load($file->id());

    $this->assertEquals('0', $file->get('metadata_cleaned')->value);
  }

  /**
   * Tests that on file insert works.
   */
  public function testOverviewFilesOperationExists(): void {
    $kernel = $this->container->get('kernel');
    $appRoot = $kernel->getAppRoot();
    $source = $appRoot . '/modules/custom/file_metadata_cleaner/tests/fixtures/London_bridge.jpeg';
    $destination = 'public://London_bridge.jpeg';

    /** @var \Drupal\Core\File\FileSystemInterface $fileSystem */
    $fileSystem = \Drupal::service('file_system');
    $fileSystem->copy($source, $destination, FileExists::Replace);

    $file = File::create(['uri' => $destination]);
    $file->setPermanent();
    $file->save();

    $adminUser = $this->drupalCreateUser(['access files overview']);
    $this->drupalLogin($adminUser);

    $this->drupalGet('/admin/content/files');
    $this->assertSession()->statusCodeEquals(200);

    $link = $this->getSession()->getPage()->findLink('Metadata');
    $this->assertNotNull($link);
  }

  /**
   * Tests that on file insert works.
   */
  public function testOverviewFilesOperationNotExists(): void {
    $destination = 'public://test.txt';

    /** @var \Drupal\Core\File\FileSystemInterface $fileSystem */
    $fileSystem = \Drupal::service('file_system');
    file_put_contents($fileSystem->realpath($destination), 'Test data.');

    $file = File::create(['uri' => $destination]);
    $file->setPermanent();
    $file->save();

    $adminUser = $this->drupalCreateUser(['access files overview']);
    $this->drupalLogin($adminUser);

    $this->drupalGet('/admin/content/files');
    $this->assertSession()->statusCodeEquals(200);

    $link = $this->getSession()->getPage()->findLink('Metadata');
    $this->assertNull($link);
  }

}
