<?php

declare(strict_types=1);

namespace Drupal\Tests\file_metadata_cleaner\Functional;

use Drupal\Core\File\FileExists;
use Drupal\file\Entity\File;
use Drupal\Tests\BrowserTestBase;

/**
 * Tests JPEG metadata processing with the ExifTool cleaner.
 *
 * @group file_metadata_cleaner
 */
class FilesMetadataFlowTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'file_metadata_cleaner',
  ];

  /**
   * The default theme required for BrowserTestBase.
   *
   * @var string
   */
  protected $defaultTheme = 'olivero';

  /**
   * Tests metadata processing of a valid JPEG file.
   */
  public function testIfProcessedIsCorrect(): void {
    $kernel = $this->container->get('kernel');
    $appRoot = $kernel->getAppRoot();
    $source = $appRoot . '/modules/custom/file_metadata_cleaner/tests/fixtures/London_bridge.jpeg';
    $destination = 'public://London_bridge.jpeg';

    /** @var \Drupal\Core\File\FileSystemInterface $fileSystem */
    $fileSystem = \Drupal::service('file_system');
    $fileSystem->copy($source, $destination, FileExists::Replace);

    $file = File::create(['uri' => $destination]);
    $file->setPermanent();
    $file->save();

    $this->drupalGet('/admin/content/files/metadata/' . $file->id());

    $adminUser = $this->drupalCreateUser(['access files overview']);
    $this->drupalLogin($adminUser);

    $this->drupalGet('/admin/content/files/metadata/' . $file->id());
    $this->assertSession()->statusCodeEquals(200);

    $this->assertSession()->pageTextContains("File has already been cleaned by File Metadata Cleaner.");

    $this->assertSession()->pageTextContains('ExifTool Version Number');

  }

  /**
   * Tests metadata processing of a valid JPEG file.
   */
  public function testIfUnprocessedIsCorrect(): void {
    $this->config('file_metadata_cleaner.settings')
      ->set('clean_on_upload', FALSE)
      ->save();

    $kernel = $this->container->get('kernel');
    $appRoot = $kernel->getAppRoot();
    $source = $appRoot . '/modules/custom/file_metadata_cleaner/tests/fixtures/London_bridge.jpeg';
    $destination = 'public://London_bridge.jpeg';

    /** @var \Drupal\Core\File\FileSystemInterface $fileSystem */
    $fileSystem = \Drupal::service('file_system');
    $fileSystem->copy($source, $destination, FileExists::Replace);

    $file = File::create(['uri' => $destination]);
    $file->setPermanent();
    $file->save();

    $adminUser = $this->drupalCreateUser(['access files overview']);
    $this->drupalLogin($adminUser);

    $this->drupalGet('/admin/content/files/metadata/' . $file->id());
    $this->assertSession()->statusCodeEquals(200);

    $this->assertSession()->pageTextContains("File hasn't been cleaned by File Metadata Cleaner yet.");

    $this->clickLink('Clean Metadata');

    $this->assertSession()->statusCodeEquals(200);
    $this->submitForm([], 'Yes, clean metadata');
    $this->drupalGet('/admin/content/files/metadata/' . $file->id());
    $this->assertSession()->statusCodeEquals(200);

    $this->assertSession()->pageTextContains("File has already been cleaned by File Metadata Cleaner.");
  }

}
