<?php

declare(strict_types=1);

namespace Drupal\Tests\file_metadata_cleaner\Functional;

use Drupal\Core\File\FileExists;
use Drupal\file\Entity\File;
use Drupal\Tests\BrowserTestBase;
use Drupal\file_metadata_cleaner\Services\Exiftool;

/**
 * Tests JPG metadata processing with the ExifTool cleaner.
 *
 * @group file_metadata_cleaner
 */
class JpgProcessorTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'file_metadata_cleaner',
  ];

  /**
   * The default theme required for BrowserTestBase.
   *
   * @var string
   */
  protected $defaultTheme = 'olivero';


  /**
   * The Exiftool service.
   *
   * @var \Drupal\file_metadata_cleaner\Services\Exiftool|null
   */
  protected ?Exiftool $exiftool = NULL;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->exiftool = $this->container->get('file_metadata_cleaner.exiftool');
  }

  /**
   * Tests metadata processing of a valid JPG file.
   */
  public function testProcessJpg(): void {
    $kernel = $this->container->get('kernel');
    $appRoot = $kernel->getAppRoot();
    $source = $appRoot . '/modules/custom/file_metadata_cleaner/tests/fixtures/London_bridge.jpg';
    $destination = 'public://London_bridge.jpg';

    /** @var \Drupal\Core\File\FileSystemInterface $fileSystem */
    $fileSystem = \Drupal::service('file_system');
    $fileSystem->copy($source, $destination, FileExists::Replace);

    $metadataUnprocessed = [
      'Orientation' => 'Horizontal (normal)',
      'GPS Position' => '51 deg 30\' 14.78" N, 0 deg 4\' 28.47" W',
    ];

    $metadata = $this->exiftool->readMetadata($source);
    foreach ($metadataUnprocessed as $key => $expectedValue) {
      $this->assertSame($expectedValue, $metadata[$key] ?? NULL, "$key (unprocessed) does not match.");
    }

    $file = File::create(['uri' => $destination]);
    $file->setPermanent();
    $file->save();

    $path = $fileSystem->realpath($file->getFileUri());

    $metadataProcessed = [
      'Orientation' => 'Horizontal (normal)',
      'GPS Position' => NULL,
    ];

    $metadata = $this->exiftool->readMetadata($path);
    foreach ($metadataProcessed as $key => $expectedValue) {
      $this->assertSame($expectedValue, $metadata[$key] ?? NULL, "$key (processed) does not match.");
    }
  }

}
