<?php

namespace Drupal\Tests\file_metadata_cleaner\Functional;

use Drupal\Core\Field\BaseFieldDefinition;
use Drupal\Tests\BrowserTestBase;

/**
 * Tests the 'Metadata Cleaned' field placement and base field registration.
 *
 * - Verifies it is second-to-last in the Files view.
 * - Ensures it is registered as a base field on file entities.
 *
 * @group file_metadata_cleaner
 */
class MetadataCleanedFieldTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'file_metadata_cleaner',
  ];

  /**
   * The default theme required for BrowserTestBase.
   *
   * @var string
   */
  protected $defaultTheme = 'olivero';

  /**
   * Tests the 'metadata_cleaned' base field is registered on file entities.
   */
  public function testBaseFieldRegistration(): void {
    /** @var \Drupal\Core\Entity\EntityFieldManagerInterface $field_manager */
    $field_manager = \Drupal::service('entity_field.manager');
    $definitions = $field_manager->getBaseFieldDefinitions('file');

    $this->assertArrayHasKey('metadata_cleaned', $definitions, 'metadata_cleaned field is defined on file entity.');

    $field = $definitions['metadata_cleaned'];
    $this->assertInstanceOf(BaseFieldDefinition::class, $field);

    $this->assertEquals('Metadata Cleaned', $field->getLabel(), 'Correct label.');
    $this->assertEquals('boolean', $field->getType(), 'Correct field type.');
    $this->assertFalse($field->getDefaultValueLiteral()[0]['value'], 'Default value is FALSE.');
  }

}
