<?php

declare(strict_types=1);

namespace Drupal\Tests\file_metadata_cleaner\Functional;

use Drupal\Core\File\FileExists;
use Drupal\file\Entity\File;
use Drupal\Tests\BrowserTestBase;
use Drupal\file_metadata_cleaner\Services\Exiftool;

/**
 * Tests PDF metadata processing with the ExifTool cleaner.
 *
 * @group file_metadata_cleaner
 */
class PdfProcessorTest extends BrowserTestBase {

  /**
   * {@inheritdoc}
   */
  protected static $modules = [
    'file_metadata_cleaner',
  ];

  /**
   * The default theme required for BrowserTestBase.
   *
   * @var string
   */
  protected $defaultTheme = 'olivero';

  /**
   * The Exiftool service.
   *
   * @var \Drupal\file_metadata_cleaner\Services\Exiftool|null
   */
  protected ?Exiftool $exiftool = NULL;

  /**
   * {@inheritdoc}
   */
  protected function setUp(): void {
    parent::setUp();
    $this->exiftool = $this->container->get('file_metadata_cleaner.exiftool');
  }

  /**
   * Tests metadata processing of a valid PDF file.
   */
  public function testProcessPdf(): void {
    $kernel = $this->container->get('kernel');
    $appRoot = $kernel->getAppRoot();
    $source = $appRoot . '/modules/custom/file_metadata_cleaner/tests/fixtures/Dinosaurs_and_castles.pdf';
    $destination = 'public://Dinosaurs_and_castles.pdf';

    /** @var \Drupal\Core\File\FileSystemInterface $fileSystem */
    $fileSystem = \Drupal::service('file_system');
    $fileSystem->copy($source, $destination, FileExists::Replace);

    $metadataUnprocessed = [
      'Title' => 'Dinosaurs and castles',
      'Author' => 'Secret Dino Author',
      'Subject' => 'This PDF is created for testing purposes only',
      'Keywords' => 'Testing, Dummy data, Dinosaurs',
      'Creator' => 'Secret Dino Creator',
      'Producer' => 'Secret Dino Producer',
    ];

    $metadata = $this->exiftool->readMetadata($source);
    foreach ($metadataUnprocessed as $key => $expectedValue) {
      $this->assertSame($expectedValue, $metadata[$key] ?? NULL, "$key (unprocessed) does not match.");
    }

    $file = File::create(['uri' => $destination]);
    $file->setPermanent();
    $file->save();

    $path = $fileSystem->realpath($file->getFileUri());

    $metadataProcessed = [
      'Title' => 'Dinosaurs and castles',
      'Author' => 'Drupal',
      'Subject' => 'This PDF is created for testing purposes only',
      'Keywords' => 'Testing, Dummy data, Dinosaurs',
      'Creator' => NULL,
      'Producer' => NULL,
    ];

    $metadata = $this->exiftool->readMetadata($path);
    foreach ($metadataProcessed as $key => $expectedValue) {
      $this->assertSame($expectedValue, $metadata[$key] ?? NULL, "$key (processed) does not match.");
    }
  }

}
