<?php

namespace Drupal\Tests\file_metadata_cleaner\Kernel;

use Drupal\KernelTests\KernelTestBase;

/**
 * Tests the availability of the PHPExiftool library and system binary.
 *
 * @group file_metadata_cleaner
 */
class ExifToolAvailabilityTest extends KernelTestBase {

  /**
   * Checks if the phpexiftool/exiftool package exists in the vendor directory.
   *
   * @coversNothing
   */
  public function testExifToolPackageInVendor(): void {
    $kernel = $this->container->get('kernel');
    $appRoot = $kernel->getAppRoot();
    $installedPackagesPath = realpath($appRoot . '/../vendor/composer/installed.json');

    $this->assertFileExists(
      $installedPackagesPath,
      'installed.json file exists in vendor directory.'
    );

    $installedJson = json_decode(file_get_contents($installedPackagesPath), TRUE);
    $this->assertIsArray($installedJson, 'installed.json is a valid JSON file.');

    $packages = $installedJson['packages'] ?? [];
    $packageNames = array_column($packages, 'name');

    $this->assertContains(
      'ahmetburkan/exiftool-binary',
      $packageNames,
      'ahmetburkan/exiftool-binary is listed in installed packages.'
    );
  }

  /**
   * Checks if the ExifTool version is available and correct.
   *
   * @coversNothing
   */
  public function testExifToolVersion(): void {
    $kernel = $this->container->get('kernel');
    $appRoot = $kernel->getAppRoot();
    $exiftoolPath = realpath($appRoot . '/../vendor/ahmetburkan/exiftool-binary/exiftool');

    $cmd = escapeshellcmd($exiftoolPath) . ' -ver';
    exec($cmd, $output, $returnVar);

    $this->assertEquals(0, $returnVar, 'ExifTool command executed successfully.');
    $this->assertNotEmpty($output, 'ExifTool version output is not empty.');
    $this->assertMatchesRegularExpression('/^\d{1,2}\.\d{1,2}$/', trim($output[0]), 'ExifTool version format matches XX.XX.');
  }

}
